==> tutti-ui-swing-1.2-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolSpeciesAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportProtocolSpeciesAction.java 678 2013-03-25 17:44:48Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.2/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolSpeciesAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import fr.ifremer.tutti.persistence.entities.protocol.SpeciesProtocol;
import fr.ifremer.tutti.persistence.entities.protocol.TuttiProtocol;
import fr.ifremer.tutti.service.protocol.TuttiProtocolImportExportService;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;
import java.util.List;

import static org.nuiton.i18n.I18n._;

/**
 * To import protocol species.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ImportProtocolSpeciesAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ImportProtocolSpeciesAction.class);

    private File file;

    public ImportProtocolSpeciesAction(EditProtocolUIHandler handler) {
        super(handler, false);
    }

    @Override
    protected boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to import
            file = TuttiUIUtil.chooseFile(
                    getContext().getMainUI(),
                    _("tutti.editProtocol.title.choose.speciesImportFile"),
                    _("tutti.editProtocol.action.chooseProtocolSpeciesFile"),
                    "^.*\\.csv", _("tutti.common.file.csv")
            );

            doAction = file != null;
        }
        return doAction;
    }

    @Override
    protected void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    protected void doAction() throws Exception {
        Preconditions.checkNotNull(file);
        if (log.isInfoEnabled()) {
            log.info("Will import protocol species file: " + file);
        }

        EditProtocolUIModel model = getModel();

        // bind to a protocol
        TuttiProtocol protocol = model.toBean();

        // import
        TuttiProtocolImportExportService service =
                getContext().getTuttiProtocolImportExportService();

        service.importProtocolSpecies(file,
                                      protocol,
                                      model.getAllCaracteristic(),
                                      model.getAllReferentSpeciesByTaxonId());

        // build rows from imported+merged protocol
        // (will also remove all synonyms of species referent used)
        List<EditProtocolSpeciesRowModel> rows =
                handler.toRows(protocol.getSpecies());

        // update species comboBox
//        getUI().getSpeciesComboBox().getHandler().sortData();
        getUI().getSpeciesComboBox().getHandler().reset();

        // update benthos comboBox
//        getUI().getBenthosComboBox().getHandler().sortData();
        getUI().getBenthosComboBox().getHandler().reset();

        // update rows in model
        model.setSpecies(rows);

        int nbSynonym = 0;
        for (SpeciesProtocol speciesProtocol : protocol.getSpecies()) {
            if (!speciesProtocol.isMadeFromAReferentTaxon()) {
                nbSynonym++;
            }
        }

        String message;
        switch (nbSynonym) {
            case 0:
                message = _("tutti.flash.info.species.imported.in.protocol",
                            file);
                break;

            case 1:
                message = _("tutti.flash.info.species.imported.in.protocol.oneReplaced",
                            file);
                break;

            default:
                message = _("tutti.flash.info.species.imported.in.protocol.severalReplaced",
                            file, nbSynonym);
        }
        sendMessage(message);
    }
}

==> tutti-ui-swing-1.3-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolSpeciesAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: ImportProtocolSpeciesAction.java 739 2013-04-05 13:36:16Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-1.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/ImportProtocolSpeciesAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import fr.ifremer.tutti.persistence.entities.protocol.SpeciesProtocol;
import fr.ifremer.tutti.persistence.entities.protocol.TuttiProtocol;
import fr.ifremer.tutti.service.protocol.TuttiProtocolImportExportService;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;
import java.util.List;

import static org.nuiton.i18n.I18n._;

/**
 * To import protocol species.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ImportProtocolSpeciesAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ImportProtocolSpeciesAction.class);

    private File file;

    public ImportProtocolSpeciesAction(EditProtocolUIHandler handler) {
        super(handler, false);
    }

    @Override
    protected boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to import
            file = TuttiUIUtil.chooseFile(
                    getContext().getMainUI(),
                    _("tutti.editProtocol.title.choose.speciesImportFile"),
                    _("tutti.editProtocol.action.chooseProtocolSpeciesFile"),
                    "^.*\\.csv", _("tutti.common.file.csv")
            );

            doAction = file != null;
        }
        return doAction;
    }

    @Override
    protected void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    protected void doAction() throws Exception {
        Preconditions.checkNotNull(file);
        if (log.isInfoEnabled()) {
            log.info("Will import protocol species file: " + file);
        }

        EditProtocolUIModel model = getModel();

        // bind to a protocol
        TuttiProtocol protocol = model.toBean();

        // import
        TuttiProtocolImportExportService service =
                getContext().getTuttiProtocolImportExportService();

        service.importProtocolSpecies(file,
                                      protocol,
                                      model.getAllCaracteristic(),
                                      model.getAllReferentSpeciesByTaxonId());

        // build rows from imported+merged protocol
        // (will also remove all synonyms of species referent used)
        List<EditProtocolSpeciesRowModel> rows =
                handler.toRows(protocol.getSpecies());

        // update species comboBox
//        getUI().getSpeciesComboBox().getHandler().sortData();
        getUI().getSpeciesComboBox().getHandler().reset();

        // update benthos comboBox
//        getUI().getBenthosComboBox().getHandler().sortData();
        getUI().getBenthosComboBox().getHandler().reset();

        // update rows in model
        model.setSpeciesRow(rows);

        getHandler().getSpeciesTableModel().setRows(rows);

        int nbSynonym = 0;
        for (SpeciesProtocol speciesProtocol : protocol.getSpecies()) {
            if (!speciesProtocol.isMadeFromAReferentTaxon()) {
                nbSynonym++;
            }
        }

        String message;
        switch (nbSynonym) {
            case 0:
                message = _("tutti.flash.info.species.imported.in.protocol",
                            file);
                break;

            case 1:
                message = _("tutti.flash.info.species.imported.in.protocol.oneReplaced",
                            file);
                break;

            default:
                message = _("tutti.flash.info.species.imported.in.protocol.severalReplaced",
                            file, nbSynonym);
        }
        sendMessage(message);
    }
}
